@@ -4,9 +4,10 @@ from google.cloud.exceptions import NotFound
 
 from skt.ye import get_spark
 
-PROJECT_ID = "sktaic-datahub"
+PROJECT_ID = "skt-datahub"
 TEMP_DATASET = "temp_1d"
-CREDENTIALS_SECRET_PATH = "gcp/sktaic-datahub/dataflow"
+LOCATION = "asia-northeast3"
+CREDENTIALS_SECRET_PATH = "gcp/skt-datahub/dataflow"
 
 
 def get_credentials():
@@ -61,7 +62,7 @@ def _get_result_schema(sql, bq_client=None, project_id=PROJECT_ID):
 
 
 def _get_result_column_type(sql, column, bq_client=None, project_id=PROJECT_ID):
-    schema = _get_result_schema(sql, bq_client)
+    schema = _get_result_schema(sql, bq_client=bq_client, project_id=project_id)
     fields = schema["fields"]
     r = [field["type"] for field in fields if field["name"] == column]
     if r:
@@ -111,7 +112,7 @@ def bq_ctas(sql, destination=None, partition_by=None, clustering_fields=None, pr
 
     bq = get_bigquery_client(project_id=project_id)
     if partition_by:
-        partition_type = _get_result_column_type(sql, partition_by, bq_client=bq)
+        partition_type = _get_result_column_type(sql, partition_by, bq_client=bq, project_id=project_id)
         if partition_type == "DATE":
             qjc = QueryJobConfig(
                 destination=destination,
@@ -192,6 +193,9 @@ def _bq_cell_magic(line, query):
     start = time.time()
     args = magic_arguments.parse_argstring(_cell_magic, line)
 
+    if args.project is None:
+        line = f"{line} --project {PROJECT_ID}"
+
     if args.params is not None:
         try:
             import ast
@@ -257,13 +261,13 @@ def load_bigquery_ipython_magic():
         raise Exception("Cannot import bigquery magic. Because execution is not on ipython.")
 
 
-def get_bigquery_client(credentials=None, project_id=PROJECT_ID):
+def get_bigquery_client(credentials=None, project_id=PROJECT_ID, location=LOCATION):
     from google.cloud import bigquery
 
     if credentials is None:
         credentials = get_credentials()
 
-    return bigquery.Client(credentials=credentials, project=project_id)
+    return bigquery.Client(credentials=credentials, project=project_id, location=location)
 
 
 def bq_table_exists(table, project_id=PROJECT_ID):
