@@ -273,6 +273,7 @@ def slack_send(
     icon_emoji=":large_blue_circle:",
     blocks=None,
     dataframe=False,
+    adot=False
 ):
     import requests
     from skt.vault_utils import get_secrets
@@ -282,7 +283,7 @@ def slack_send(
 
         text = "```" + tabulate(text, tablefmt="simple", headers="keys") + "```"
 
-    token = get_secrets("slack")["bot_token"]["airflow"]
+    token = get_secrets("airflow_k8s/adot_slack/slack_alarmbot_token")["token"] if adot else get_secrets("slack")["bot_token"]["airflow"]
     proxy = get_secrets("proxy")["proxy"]
     proxies = {
         "http": proxy,
